@@ -8,7 +8,9 @@
 #ifndef _denormals_
 #define _denormals_
 
-#define undenormalise(sample) if(((*(unsigned int*)&sample)&0x7f800000)==0) sample=0.0f
+// this macro is broken! http://music.columbia.edu/pipermail/linux-audio-user/2004-July/013489.html
+// #define undenormalise(sample) if(((*(unsigned int*)(void *)&sample)&0x7f800000)==0) sample=0.0f
+static inline float undenormalise(volatile float s) { s += 9.8607615E-32f; return s - 9.8607615E-32f; }
 
 #define nuke_denormals(value) if(((*(unsigned int *)&(value))&0x7f800000)<0x08000000) value=0.0f
 
