@@ -7,18 +7,14 @@
 #include "../UpdateListener.h"
 #include "Request.h"
 
-#include <gtkmm/dialog.h>
-#include <gtkmm/label.h>
-#include <gtkmm/combo.h>
-#include <gtkmm/button.h>
-#include <gtkmm/menu.h>
+#include <gtkmm.h>
 
 class MidiController;
 class PresetController;
 class ControllerMapDialog : public Gtk::Window, public UpdateListener
 {
 public:
-		ControllerMapDialog	( int pipe_d,
+		ControllerMapDialog	(
 					MidiController* mc,
 					PresetController* pc );
 		~ControllerMapDialog	( );
@@ -33,11 +29,9 @@ public:
     
 private:
 	gboolean		supress_callback;
-	int			piped;
     
 	MidiController		*midi_controller;
 	PresetController	*preset_controller;
-	Request			request;
 
 	Gtk::Menu		*m_menu_controllers;
 	Gtk::Button		*m_button_controller;
