@@ -5,10 +5,7 @@
 #ifndef _EDITOR_PANEL_H
 #define _EDITOR_PANEL_H
 
-#include <gtkmm/box.h>
-#include <gtkmm/frame.h>
-#include <gtkmm/fixed.h>
-#include <gtkmm/style.h>
+#include <gtkmm.h>
 
 // forward definition of classes: speeds up compilation
 
@@ -22,11 +19,9 @@ class RadioButtonParameterView;
 class EditorPanel : public Gtk::VBox
 {
  public:
-  EditorPanel	( Preset* preset, int piped );
+  EditorPanel	( Preset* preset );
   ~EditorPanel	( );
 	
-  void		set_x_font	( const char *x_font_desc );
-
  private:
   virtual void	on_realize	( );
 	
