@@ -5,6 +5,7 @@
  
 #include "GUI.h"
 
+#include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <list>
@@ -43,17 +44,20 @@ enum {
 	evConfig,
 };
 
-
 int
 GUI::delete_event_impl(GdkEventAny *)
 {
-	MessageDialog dlg (*this, "Really quit amSynth?\n\nYou will lose any changes\nwhich you haven't explicitly commited", false, MESSAGE_QUESTION, BUTTONS_YES_NO, true);
-	if (RESPONSE_YES == dlg.run()) hide_all();
+	if (m_presetIsNotSaved) {
+		MessageDialog dlg (*this, "Really quit amSynth?\n\nYou will lose any changes\nwhich you haven't explicitly commited", false, MESSAGE_QUESTION, BUTTONS_YES_NO, true);
+		if (RESPONSE_YES != dlg.run())
+			return false;
+	}
+	hide_all();
 	return true;
 }
 
 GUI::GUI( Config & config, MidiController & mc, VoiceAllocationUnit & vau,
-		int pipe_write, GenericOutput *audio, const char *title )
+		  GenericOutput *audio, const char *title )
 :	controller_map_dialog(NULL)
 ,	clipboard_preset (new Preset)
 {
@@ -61,7 +65,6 @@ GUI::GUI( Config & config, MidiController & mc, VoiceAllocationUnit & vau,
 	
 	this->config = &config;
 	this->midi_controller = &mc;
-	this->m_pipe_write = pipe_write;
 	this->vau = &vau;
 	this->audio_out = audio;
 	
@@ -73,15 +76,13 @@ GUI::GUI( Config & config, MidiController & mc, VoiceAllocationUnit & vau,
 	set_title(m_baseName);
 	set_resizable(false);
         
-        m_requestUpdate.slot = mem_fun(*this, &GUI::onUpdate);
-
 	active_param = 0;
 
 
 //	style = Gtk::Style::create ( );
 	
 	
-	presetCV = new PresetControllerView(pipe_write, *this->vau);
+	presetCV = new PresetControllerView(*this->vau);
 
 	//
 	// the preset rename dialog
@@ -145,6 +146,7 @@ GUI::GUI( Config & config, MidiController & mc, VoiceAllocationUnit & vau,
 	about_authors.push_back("Adam Sampson");
 	about_authors.push_back("Martin Tarenskeen");
 	about_authors.push_back("Adrian Knoth");
+	about_authors.push_back("Samuli Suominen");
 	aboutDlg.set_authors(about_authors);
 	std::list<std::string> about_artists;
 	about_artists.push_back("Saul Cross");
@@ -245,9 +247,9 @@ GUI::create_menus	( )
 
 	MenuItem *menu_item = manage (new MenuItem("Virtual Keyboard"));
 	menu_item->signal_activate().connect(sigc::bind(mem_fun(*this, &GUI::event_handler),(int)evVkeybd));
-	if (config->alsa_seq_client_id==0) menu_item->set_sensitive( false );
-	// test for presence of vkeybd.
-	if (command_exists ("vkeybd") != 0) menu_item->set_sensitive( false );
+	// vkeybd must exist, and we must be using ALSA MIDI
+	if (config->alsa_seq_client_id == 0 || command_exists("vkeybd") != 0)
+		menu_item->set_sensitive( false );
 	list_utils.push_back (*menu_item);
 
 	menu_item = manage (new MenuItem("Record to .wav file..."));
@@ -335,7 +337,7 @@ GUI::init()
 {
 	Preset *preset = &(preset_controller->getCurrentPreset());
 	
-	editor_panel = new EditorPanel (preset, m_pipe_write);
+	editor_panel = new EditorPanel (preset);
 	
 	adj_midi = manage (new Gtk::Adjustment(config->midi_channel,0,16,1));
 	adj_midi->signal_value_changed().connect (mem_fun (*this, &GUI::changed_midi_channel));
@@ -389,16 +391,28 @@ GUI::init()
 
 	statusBar.pack_start (*manage(new Gtk::VSeparator), PACK_SHRINK);
 	
-	status = "Realtime : ";
-	if (this->config->current_audio_driver!="jack" && 
-		this->config->current_audio_driver!="JACK" &&
-		config->realtime
-		){ status += "YES"; }
-	else { status += "NO"; }
-	statusBar.pack_start (*manage(new Gtk::Label (status)), PACK_SHRINK, padding);
+#ifdef ENABLE_REALTIME
+	if (config->current_audio_driver_wants_realtime)
+	{
+		status = "Realtime : ";
+		status += config->realtime ? "YES" : "NO";
+		statusBar.pack_start(*manage(new Gtk::Label (status)), PACK_SHRINK, padding);
+	}
+#endif
 	
 	show_all();
 	
+	//
+	// show any error dialogs after entering gtk's run loop, otherwise the user
+	// will see the window's controls adjust their layout after dismissing the
+	// dialog (which looks ugly).
+	//
+	CALL_ON_GUI_THREAD( *this, &GUI::post_init );
+}
+
+void
+GUI::post_init()
+{
 	bool bad_config = false;
 	
 	if (config->current_audio_driver.empty())
@@ -430,13 +444,16 @@ GUI::init()
 		return;
 	}
 	
+#ifdef ENABLE_REALTIME
 	// show realtime warning message if necessary
-	if (!config->realtime && config->current_audio_driver != "jack" && config->current_audio_driver != "JACK")
+	if (config->current_audio_driver_wants_realtime == 1 &&
+		config->realtime == 0)
 	{
 		MessageDialog dlg (*this, "amSynth could not set realtime priority");
 		dlg.set_secondary_text ("You may experience audio buffer underruns resulting in 'clicks' in the audio.\n\nThis is most likely because the program is not SUID root.\n\nUsing the JACK audio subsystem can also help");
 		dlg.run();
 	}
+#endif
 }
 
 
@@ -459,6 +476,7 @@ GUI::event_handler(const int e)
 	
 	case evPresetRenameOk:
 		preset_controller->getCurrentPreset().setName(preset_rename_entry.get_text());
+		onUpdate();
 		presetCV->update();
 		preset_rename.hide();
 		break;
@@ -544,12 +562,9 @@ GUI::event_handler(const int e)
 	
 	case evVkeybd:
 	    {
-		    string tmp = "vkeybd --addr ";
-		    char tc[5];
-		    sprintf( tc, "%d", config->alsa_seq_client_id );
-		    tmp += string(tc);
-		    tmp += ":0 &";
-		    system( tmp.c_str() );
+			char tmp[255] = "";
+			snprintf(tmp, sizeof(tmp), "vkeybd --addr %d:0", config->alsa_seq_client_id);
+			command_run(tmp);
 	    }
 		break;
 	
@@ -564,6 +579,7 @@ GUI::event_handler(const int e)
 	{
 		ConfigDialog dlg (*this, *config);
 		dlg.run ();
+		break;
 	}
 		
 	default:
@@ -603,15 +619,49 @@ GUI::~GUI()
 void
 GUI::update()
 {
-    write(m_pipe_write, &m_requestUpdate, sizeof(Request));
-}
-void
-GUI::onUpdate()
-{
-    set_title(m_baseName + preset_controller->getCurrentPreset().getName());
-    presetCV->update();
+	CALL_ON_GUI_THREAD( *this, &GUI::onUpdate );
 }
 
+void
+GUI::onUpdate()	// called whenever the preset selection has changed
+{
+	update_title();
+	UpdateParameterOnMainThread((Param)-1, 0); // to update the '*' in window title
+    presetCV->update(); // note: PresetControllerView::update() is expensive
+}
+
+void
+GUI::update_title()
+{
+	std::string title = m_baseName + preset_controller->getCurrentPreset().getName();
+	if (m_presetIsNotSaved) {
+		title += std::string(" *");
+	}
+	set_title(title);
+}
+
+void
+GUI::UpdateParameter(Param paramID, float paramValue)
+{
+	call_slot_on_gui_thread(
+		sigc::bind( 
+			sigc::mem_fun(
+				*this, &GUI::UpdateParameterOnMainThread
+			),
+			paramID, paramValue
+		)
+	);
+}
+
+void
+GUI::UpdateParameterOnMainThread(Param, float)	// called whenever a parameter value has changed
+{
+	bool isModified = preset_controller->isCurrentPresetModified();
+	if (m_presetIsNotSaved != isModified) {
+		m_presetIsNotSaved = isModified;
+		update_title();
+	}
+}
 
 void 
 GUI::run()
@@ -631,7 +681,14 @@ GUI::setPresetController(PresetController & p_c)
     presetCV->setPresetController(*preset_controller);
 	onUpdate();
 	
-    controller_map_dialog = new ControllerMapDialog(m_pipe_write, midi_controller, preset_controller);
+	// register for notification of all parameter changes
+	Preset &preset = preset_controller->getCurrentPreset();
+	unsigned paramCount = preset.ParameterCount();
+	for (unsigned i=0; i<paramCount; i++) {
+		preset.getParameter(i).addUpdateListener(*this);
+	}
+	
+    controller_map_dialog = new ControllerMapDialog(midi_controller, preset_controller);
 }
 
 void
@@ -687,29 +744,38 @@ GUI::bank_save_as	( )
 	}
 }
 
+static gchar *which(gchar *command)
+{
+	gint exit_status = -1;
+	gchar *standard_output = NULL;
+	gchar *argv[] = { (gchar *)"/usr/bin/which", (gchar *)command };
+	g_spawn_sync(NULL, argv, NULL, G_SPAWN_STDERR_TO_DEV_NULL, NULL, NULL, &standard_output, NULL, &exit_status, NULL);
+	if (exit_status != 0)
+	{
+		g_free(standard_output);
+		return NULL;
+	}
+	return standard_output;
+}
+
+// returns 0 if executable was found
 int
 GUI::command_exists	(const char *command)
 {
-	string test_command = "which ";
-	test_command += command;
-	test_command += " &> /dev/null";
-	
-	int res = system (test_command.c_str ());
-	
-	if (WEXITSTATUS (res) == 0)
-		// exit code 0 - program exists in $PATH
-		return 0;
-	else
-		return 1;
+	gchar *path = which((gchar *)command);
+	if (path) g_free(path);
+	return path == NULL ? 1 : 0;
 }
 
 void
 GUI::command_run	(const char *command)
 {
-	string full_command = command;
-	full_command += " &";
+	// TODO: would be better to fork() and exec()
 	
-	system (full_command.c_str ());
+	string full_command = std::string(command) + std::string(" &");
+	// returns 0 even if command could not be run
+	int result = system(full_command.c_str());
+	result = 0;
 }
 
 void
@@ -724,18 +790,3 @@ GUI::changed_voices	( )
 	config->polyphony = (int)(adj_voices->get_value ());
 	if (vau) vau->SetMaxVoices (config->polyphony);
 }
-
-void GUI::GdkInputFunction(gpointer data, gint source, GdkInputCondition condition)
-{
-	static Request req;
-	if (read (source, &req, sizeof(Request)) == sizeof(Request)) req.slot();
-
-}
-
-void ShowModalErrorMessage(const string & msg)
-{
-	MessageDialog dlg ("amSynth", false, MESSAGE_ERROR, BUTTONS_OK, true);
-	dlg.set_secondary_text(msg);
-	dlg.run();
-}
-
