@@ -5,10 +5,7 @@
 #ifndef _KNOB_H
 #define _KNOB_H
 
-#include <gtkmm/misc.h>
-#include <gtkmm/main.h>
-#include <gtkmm/style.h>
-#include <gtkmm/adjustment.h>
+#include <gtkmm.h>
  
 // the knob turns from 30 degrees to 330 degrees, so graphics should fit that..
 
@@ -32,7 +29,7 @@ protected:
 private:
 	void mouse_pos_change					(gint x, gint y);
 	Glib::RefPtr<Gdk::Pixbuf> pixmap;
-	Glib::RefPtr<Gtk::Adjustment> adj;
+	Gtk::Adjustment *adj;
 	gint widget_x, widget_y;
 	gint frame, width, height, frames, center_x, center_y;
 };
