@@ -5,11 +5,7 @@
 #ifndef _PARAMETERKNOB_H
 #define _PARAMETERKNOB_H
 
-#include <gtkmm/box.h>
-#include <gtkmm/menu.h>
-#include <gtkmm/frame.h>
-#include <gtkmm/label.h>
-#include <gtkmm/adjustment.h>
+#include <gtkmm.h>
 #include <stdlib.h>
 #include "ParameterView.h"
 #include "Knob.h"
@@ -18,7 +14,7 @@
 class ParameterKnob : public ParameterView, public Gtk::VBox
 {
 public:
-  ParameterKnob( int pipe_d );
+  ParameterKnob();
  
   void setParameter(Parameter & param);
   void setName(string name);
@@ -26,7 +22,6 @@ public:
   Gtk::Widget * getGtkWidget();
   void drawValue( bool draw );
   void setFrames(const Glib::RefPtr<Gdk::Pixbuf>&, int x, int y, int numFrames);
-  void set_style( Gtk::Style& style );
 	
 private:
   void updateParam(Gtk::Adjustment * _adj);
