@@ -5,9 +5,8 @@
 #include "ParameterSwitch.h"
 #include <iostream>
 
-ParameterSwitch::ParameterSwitch( int pipe_d )
-:	ParameterView (pipe_d)
-,	supress_param_callback (false)
+ParameterSwitch::ParameterSwitch()
+:	supress_param_callback (false)
 {
 	check_button.add (label);
 	add (check_button);
@@ -56,9 +55,3 @@ ParameterSwitch::_update_()
 	supress_param_callback = false;
 }
 
-void 
-ParameterSwitch::set_style( Gtk::Style& style )
-{
-//	label.set_style( style );
-//	check_button.get_child()->set_style( style );
-}
