@@ -5,22 +5,19 @@
 #ifndef _PARAMETERSWITCH_H
 #define _PARAMETERSWITCH_H
 
-#include <gtkmm/box.h>
-#include <gtkmm/label.h>
-#include <gtkmm/checkbutton.h>
+#include <gtkmm.h>
 #include <stdlib.h>
 
 #include "ParameterView.h"
 
 class ParameterSwitch : public ParameterView, public Gtk::VBox {
   public:
-    ParameterSwitch( int pipe_d );
+    ParameterSwitch();
 
     void setParameter(Parameter & param);
     void setName(string name);
 	void _update_();
 	void toggle_handler();
-	void set_style( Gtk::Style& style );
   private:
 	Gtk::CheckButton check_button;
 	Gtk::Label label;
