@@ -5,11 +5,7 @@
 #ifndef _RADIOBUTTONPARAMETERVIEW_H
 #define _RADIOBUTTONPARAMETERVIEW_H
 
-#include <gtkmm/box.h>
-#include <gtkmm/frame.h>
-#include <gtkmm/label.h>
-#include <gtkmm/radiobutton.h>
-#include <gtkmm/style.h>
+#include <gtkmm.h>
 #include <stdlib.h>
 #include <list>
 #include <string>
@@ -19,12 +15,11 @@
 
 class RadioButtonParameterView : public ParameterView, public Gtk::VBox {
 public:
-	RadioButtonParameterView( int pipe_d );
+	RadioButtonParameterView();
 	void setName( string name );
 	void setDescription( int button, string text );
 	void setParameter( Parameter & param );
 	void _update_();
-	void set_style( Gtk::Style& style );
 private:
 	void toggle_handler( int button );
 	gfloat last_toggle;
