@@ -7,6 +7,7 @@
 
 #include <iostream>
 #include <string.h>
+#include <stdio.h>
 #include <stdlib.h>
 
 #define SIZEOF_ARRAY(a) (sizeof(a) / sizeof(a[0]))
@@ -116,6 +117,7 @@ JackOutput::init	( Config & config )
 	
 	return 0;
 #endif
+	UNUSED_PARAM(config);
 	return -1;
 }
 
