@@ -30,8 +30,10 @@ public:
 	Preset&	getPreset			(const int preset) { return presets[preset]; }
 	Preset&	getPreset			(const string name);
 
+	bool	isCurrentPresetModified() { return !currentPreset.isEqual(presets[currentPresetNo]); }
+	
 	// Commit the current preset to memory
-	void	commitPreset		() { presets[currentPresetNo] = currentPreset; }
+	void	commitPreset		() { presets[currentPresetNo] = currentPreset; notify(); }
 
 	// Selects a new, unused preset ready for editing.
 	int		newPreset			();
