@@ -30,6 +30,8 @@ ALSAAudioDriver::write(float *buffer, int frames)
 	free( audiobuf );
 	return 0;
 #else
+	UNUSED_PARAM(buffer);
+	UNUSED_PARAM(frames);
 	return -1;
 #endif
 }
@@ -59,11 +61,15 @@ ALSAAudioDriver::open( Config & config )
 	
 	config.sample_rate = snd_pcm_hw_params_get_rate( hw_params, 0 );
 	config.current_audio_driver = "ALSA";
+#ifdef ENABLE_REALTIME
+	config.current_audio_driver_wants_realtime = 1;
+#endif
 	
 	this->config = &config;
 
 	return 0;
 #else
+	UNUSED_PARAM(config);
 	return -1;
 #endif
 }
@@ -108,3 +114,4 @@ ALSAAudioDriver::~ALSAAudioDriver()
 {
   close();
 }
+
